find_parent_header

Function find_parent_header 

pub fn find_parent_header(
    block_header: &BlockHeader,
    storage: &Store,
) -> Result<BlockHeader, ChainError>
Searchs the header of the parent block header. If the parent header is missing, Returns a ChainError::ParentNotFound. If the storage has an error it propagates it