Module fork_choice

Module fork_choice 

Constants

REORG_DEPTH_LIMIT
Maximum number of canonical blocks ethrex can revert in a single forkchoice update.

Functions

apply_fork_choice
Applies new fork choice data to the current blockchain. It performs validity checks: