pub fn create_payload(
args: &BuildPayloadArgs,
storage: &Store,
extra_data: Bytes,
) -> Result<Block, ChainError>Expand description
Creates a new payload based on the payload arguments
pub fn create_payload(
args: &BuildPayloadArgs,
storage: &Store,
extra_data: Bytes,
) -> Result<Block, ChainError>Creates a new payload based on the payload arguments