pub struct TransactionQueue { /* private fields */ }Expand description
A struct representing suitable mempool transactions waiting to be included in a block
Implementations
Sourceimpl TransactionQueue
impl TransactionQueue
Sourcepub fn peek(&self) -> Option<HeadTransaction>
pub fn peek(&self) -> Option<HeadTransaction>
Returns the head transaction with the highest tip If there is more than one transaction with the highest tip, return the one with the lowest timestamp
Sourcepub fn pop(&mut self)
pub fn pop(&mut self)
Removes current head transaction and all transactions from the given sender
Sourcepub fn shift(&mut self) -> Result<(), ChainError>
pub fn shift(&mut self) -> Result<(), ChainError>
Remove the top transaction Add a tx from the same sender to the head transactions