pub struct HeadTransaction {
pub tx: MempoolTransaction,
pub tip: U256,
}Fields
tx: MempoolTransactiontip: U256Methods from Deref<Target = Transaction>
pub fn tx_type(&self) -> TxType
pub fn effective_gas_price(&self, base_fee_per_gas: Option<u64>) -> Option<U256>
pub fn cost_without_base_fee(&self) -> Option<U256>
pub fn fee_token(&self) -> Option<H160>
pub fn sender(&self, crypto: &dyn Crypto) -> Result<H160, CryptoError>
pub fn gas_limit(&self) -> u64
pub fn gas_price(&self) -> U256
pub fn to(&self) -> TxKind
pub fn value(&self) -> U256
pub fn max_priority_fee(&self) -> Option<u64>
pub fn chain_id(&self) -> Option<u64>
pub fn access_list(&self) -> &Vec<(H160, Vec<H256>)>
pub fn nonce(&self) -> u64
pub fn data(&self) -> &Bytes
pub fn blob_versioned_hashes(&self) -> Vec<H256>
pub fn max_fee_per_blob_gas(&self) -> Option<U256>
pub fn is_contract_creation(&self) -> bool
pub fn is_privileged(&self) -> bool
pub fn max_fee_per_gas(&self) -> Option<u64>
pub fn hash(&self) -> H256
pub fn gas_tip_cap(&self) -> U256
pub fn gas_fee_cap(&self) -> U256
Sourcepub fn effective_gas_tip(&self, base_fee: Option<u64>) -> Option<U256>
pub fn effective_gas_tip(&self, base_fee: Option<u64>) -> Option<U256>
Returns the effective tip per gas for this transaction.
Returns None if the transaction’s fee cap is below the base fee (i.e. the
transaction cannot pay for its inclusion).
Sourcepub fn protected(&self) -> bool
pub fn protected(&self) -> bool
Returns whether the transaction is replay-protected. For more information check out EIP-155
Sourcepub fn encode_canonical(&self, buf: &mut dyn BufMut)
pub fn encode_canonical(&self, buf: &mut dyn BufMut)
Encodes a transaction in canonical format
Based on [EIP-2718]
Transactions can be encoded in the following formats:
A) TransactionType || Transaction (Where Transaction type is an 8-bit number between 0 and 0x7f, and Transaction is an rlp encoded transaction of type TransactionType)
B) LegacyTransaction (An rlp encoded LegacyTransaction)
Sourcepub fn encode_canonical_to_vec(&self) -> Vec<u8> ⓘ
pub fn encode_canonical_to_vec(&self) -> Vec<u8> ⓘ
Encodes a transaction in canonical format into a newly created buffer
Based on [EIP-2718]
Transactions can be encoded in the following formats:
A) TransactionType || Transaction (Where Transaction type is an 8-bit number between 0 and 0x7f, and Transaction is an rlp encoded transaction of type TransactionType)
B) LegacyTransaction (An rlp encoded LegacyTransaction)
Sourcepub fn encode_canonical_len(&self) -> usize
pub fn encode_canonical_len(&self) -> usize
Canonical-encoded length without allocating a buffer. Counts the
1-byte type prefix for typed txs (EIP-2718) plus the inner RLP
payload length. Use this when only the size is needed (e.g.
admission-time size caps) to avoid encode_canonical_to_vec().len().